import { BLOCK_SIZE, STAGE_WIDTH, STAGE_HEIGHT } from '../level/def'

export default function useLightMap(ctx: CanvasRenderingContext2D) {
  const W = ((STAGE_WIDTH + 2) * BLOCK_SIZE)
  const H = ((STAGE_HEIGHT + 2) * BLOCK_SIZE)

  const playerX = (W - BLOCK_SIZE) / 2 + BLOCK_SIZE / 4
  const playerY = H / 2 - BLOCK_SIZE / 2
  const playerLightSize = BLOCK_SIZE * 1.8

  function drawPlayerLight(tx: number, ty: number) {
    const playerLight = ctx.createRadialGradient(
      playerX - tx, playerY - ty, 0,
      playerX - tx, playerY - ty, playerLightSize
    )

    // Add three color stops
    playerLight.addColorStop(0.0, "#FFCF");
    playerLight.addColorStop(1, "#FFC0");

    // Set the fill style and draw a rectangle
    ctx.fillStyle = playerLight;
    ctx.fillRect(0, 0, W, H)
  }

  // TODO: support light barrier
  function draw(x:number, y:number, tx:number, ty:number, time:number) {
    if (time > 900 || time < 100) {
      ctx.fillStyle = `hsl(0, 0%, 20%)`
    } else if (time < 250) {
      const s = Math.round((time - 100) / 1.5) // 0-100%
      const l = Math.round((time - 100) / 1.875) + 20 // 20-100%
      ctx.fillStyle = `hsl(0, ${s}%, ${l}%)`
    // } else if (t < 700) {
    //   ctx.fillStyle = `hsl(0, ${}%, ${}%)`
    } else {
      ctx.fillStyle = `hsl(0, 0%, 100%)`
    }
    ctx.fillRect(0, 0, W, H)
    drawPlayerLight(tx, ty)
  }

  return { draw }
}
